import{s as r,b as e,a,S as i}from"./chunk-OW32GOEJ-iz88wHBB.js";import{_ as s}from"./mermaid-vendor-D8UMrdza.js";import"./chunk-BFAMUDN2-DWjBMZTp.js";import"./chunk-SKB7J2MH-DueXnF7h.js";import"./feature-graph-7h-VS-iL.js";import"./react-vendor-DEwriMA6.js";import"./graph-vendor-B-X5JegA.js";import"./ui-vendor-CeCm8EER.js";import"./utils-vendor-BysuhMZA.js";var f={parser:a,get db(){return new i(2)},renderer:e,styles:r,init:s(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{f as diagram};
